pub enum Error {
UnknownMessageType(u8),
InvalidMessage(String),
AgentCommunicationError(Error),
SSHKey(Error),
SSHEncoding(Error),
RemoteFailure,
}Expand description
This enum represents the different Errors that might be returned by this crate.
Variants
UnknownMessageType(u8)
A message with an unknown type field was received.
InvalidMessage(String)
There was a failure parsing the message
AgentCommunicationError(Error)
There was an io::Error communicating with the agent
SSHKey(Error)
An operation returned an ssh_key::Error wrapped in this variant.
SSHEncoding(Error)
There was a failure to decode or encode an SSH key or certificate.
RemoteFailure
An operation returned the Failure message from the remote ssh-agent.