Enum ssh_agent_client_rs::Error
source · pub enum Error {
UnknownMessageType,
InvalidData(Option<String>),
IO(Option<String>, Error),
SSHKey(Error),
RemoteFailure,
}Expand description
This enum represents the different Errors that might be returned by this crate.
Variants
UnknownMessageType
A message with an unknown type field was received.
InvalidData(Option<String>)
An invalid message was received, optionally holding a String with additional detail.
IO(Option<String>, Error)
An operation returned a std::io::Error, enclosed with in the value optionally along with a String detailing the context when the error occurred.
SSHKey(Error)
An operation returned a ssh_key::Error wrapped in this variant.
RemoteFailure
An operation returned the Failure message from the remote ssh-agent.